# eric7.DebugClients.Python.eric7dbgstub

Module implementing a debugger stub for remote debugging.

### Global Attributes

__scriptname
debugger
ericpath
modDir

### Classes

None

### Functions

initDebugger | Module function to initialize a debugger for remote debugging.
runcall | Module function mimicing the Pdb interface.
setScriptname | Module function to set the scriptname to be reported back to the IDE.
startDebugger | Module function used to start the remote debugger.

## initDebugger

initDebugger(kind="standard")

Module function to initialize a debugger for remote debugging.

kind
  type of debugger ("standard" or "threads")

Return:
  flag indicating success (boolean)

Raises ValueError:
  raised to indicate a wrong debugger kind

Up

## runcall

runcall(func, *args)

Module function mimicing the Pdb interface.

func
  function to be called (function object)
*args
  arguments being passed to func

Return:
  the function result

Up

## setScriptname

setScriptname(name)

Module function to set the scriptname to be reported back to the IDE.

name
  absolute pathname of the script (string)

Up

## startDebugger

startDebugger(enableTrace=True, exceptions=True, tracePython=False, redirect=True)

Module function used to start the remote debugger.

enableTrace
  flag to enable the tracing function (boolean)
exceptions
  flag to enable exception reporting of the IDE (boolean)
tracePython
  flag to enable tracing into the Python library (boolean)
redirect
  flag indicating redirection of stdin, stdout and stderr (boolean)

Up